import { createContext, createSignal, useContext } from "solid-js";

const OverviewContext = createContext();

export default function OverviewProvider(props: any) {
  const [stats, setStats] = createSignal<{ [id: string]: any }>({
    "crystal.health": 100,
    "crystal.maxHealth": 100,
  });

  const store = [
    stats,
    {
      set(id: string, value: any) {
        const original = structuredClone(stats());
        original[id] = value;
        setStats(original);
      },
      unset(id: string) {
        const original = structuredClone(stats());
        delete original[id];
        setStats(original);
      },
    },
  ];

  return (
    <OverviewContext.Provider value={store}>
      {props.children}
    </OverviewContext.Provider>
  );
}

export function useOverview(): any[2] {
  return useContext(OverviewContext);
}
